Exception: OFX::Errors::UnsupportedVersionError
- Defined in:
- lib/ofx_kit/errors/unsupported_version_error.rb
Overview
Raised when the OFX version declared in the file is not supported.
Instance Attribute Summary collapse
-
#version ⇒ Object
readonly
The unsupported version string found in the file (String).
Instance Method Summary collapse
-
#initialize(version) ⇒ UnsupportedVersionError
constructor
Creates a new error for the given unsupported
versionstring.
Constructor Details
#initialize(version) ⇒ UnsupportedVersionError
Creates a new error for the given unsupported version string.
14 15 16 17 |
# File 'lib/ofx_kit/errors/unsupported_version_error.rb', line 14 def initialize(version) @version = version super("Unsupported OFX version: #{version}") end |
Instance Attribute Details
#version ⇒ Object (readonly)
The unsupported version string found in the file (String).
10 11 12 |
# File 'lib/ofx_kit/errors/unsupported_version_error.rb', line 10 def version @version end |