Exception: OFX::InvalidBodyError
- Inherits:
-
ParseError
- Object
- StandardError
- Error
- ParseError
- OFX::InvalidBodyError
- Defined in:
- lib/ofx_kit/errors.rb
Overview
Raised when the OFX file body cannot be parsed into a valid document.
Raised when the OFX file body cannot be parsed into a valid document.