Exception: OFX::UnsupportedVersionError

Inherits:
Error
  • Object
show all
Defined in:
lib/ofx_kit/errors.rb

Overview

Raised when the OFX version declared in the file is not supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ UnsupportedVersionError

Returns a new instance of UnsupportedVersionError.

Parameters:

  • version (String)

    the unsupported OFX version string



22
23
24
25
# File 'lib/ofx_kit/errors.rb', line 22

def initialize(version)
  @version = version
  super("Unsupported OFX version: #{version}")
end

Instance Attribute Details

#versionString (readonly)

Returns the unsupported version string found in the file.

Returns:

  • (String)

    the unsupported version string found in the file



19
20
21
# File 'lib/ofx_kit/errors.rb', line 19

def version
  @version
end