Exception: OFX::Errors::UnsupportedVersionError

Inherits:
Error
  • Object
show all
Defined in:
lib/ofx_kit/errors/unsupported_version_error.rb

Overview

Raised when the OFX version declared in the file is not supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ UnsupportedVersionError

Creates a new error for the given unsupported version string.



14
15
16
17
# File 'lib/ofx_kit/errors/unsupported_version_error.rb', line 14

def initialize(version)
  @version = version
  super("Unsupported OFX version: #{version}")
end

Instance Attribute Details

#versionObject (readonly)

The unsupported version string found in the file (String).



10
11
12
# File 'lib/ofx_kit/errors/unsupported_version_error.rb', line 10

def version
  @version
end