Exception: OFX::UnsupportedVersionError
- Defined in:
- lib/ofx_kit/errors.rb
Overview
Raised when the OFX version declared in the file is not supported.
Instance Attribute Summary collapse
-
#version ⇒ String
readonly
The unsupported version string found in the file.
Instance Method Summary collapse
-
#initialize(version) ⇒ UnsupportedVersionError
constructor
A new instance of UnsupportedVersionError.
Constructor Details
#initialize(version) ⇒ UnsupportedVersionError
Returns a new instance of UnsupportedVersionError.
22 23 24 25 |
# File 'lib/ofx_kit/errors.rb', line 22 def initialize(version) @version = version super("Unsupported OFX version: #{version}") end |
Instance Attribute Details
#version ⇒ String (readonly)
Returns the unsupported version string found in the file.
19 20 21 |
# File 'lib/ofx_kit/errors.rb', line 19 def version @version end |